<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="el_GR">
<context>
    <name>QObject</name>
    <message>
        <location filename="../src/core/RUnit.cpp" line="+272"/>
        <source>None</source>
        <translation type="unfinished">Κανένα</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Inch</source>
        <translation type="unfinished">Ίντσα</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Foot</source>
        <translation type="unfinished">Πόδι</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Mile</source>
        <translation type="unfinished">Μίλι</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Millimeter</source>
        <translation type="unfinished">Millimeter</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Centimeter</source>
        <translation type="unfinished">Εκατοστόμετρο</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Meter</source>
        <translation type="unfinished">Μετρητής</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Kilometer</source>
        <translation type="unfinished">Χιλιόμετρα</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Microinch</source>
        <translation type="unfinished">Microinch</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Mil</source>
        <translation type="unfinished">Mil</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Yard</source>
        <translation type="unfinished">Αυλή</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Angstrom</source>
        <translation type="unfinished">Angstrom</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Nanometer</source>
        <translation type="unfinished">Νανόμετρο</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Micron</source>
        <translation type="unfinished">Micron</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Decimeter</source>
        <translation type="unfinished">Δεκάμετρο</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Decameter</source>
        <translation type="unfinished">Δεκάμετρος</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Hectometer</source>
        <translation type="unfinished">Hectometer</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Gigameter</source>
        <translation type="unfinished">Gigameter</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Astro</source>
        <translation type="unfinished">Astro</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Lightyear</source>
        <translation type="unfinished">Lightyear</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Parsec</source>
        <translation type="unfinished">Parsec</translation>
    </message>
</context>
<context>
    <name>RColor</name>
    <message>
        <location filename="../src/core/RColor.cpp" line="+340"/>
        <source>By Layer</source>
        <translation type="unfinished">Με στρώμα</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>By Block</source>
        <translation type="unfinished">Με μπλοκ</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Red</source>
        <translation type="unfinished">Κόκκινο</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Green</source>
        <translation type="unfinished">Πράσινο</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Blue</source>
        <translation type="unfinished">Μπλε</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Cyan</source>
        <translation type="unfinished">Κυανό</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Magenta</source>
        <translation type="unfinished">Ματζέντα</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Yellow</source>
        <translation type="unfinished">Κίτρινο</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Orange</source>
        <translation type="unfinished">Πορτοκαλί</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Dark Red</source>
        <translation type="unfinished">Σκούρο κόκκινο</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Dark Green</source>
        <translation type="unfinished">Σκούρο πράσινο</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Dark Blue</source>
        <translation type="unfinished">Σκούρο μπλε</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Dark Cyan</source>
        <translation type="unfinished">Σκούρο κυανό</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Dark Magenta</source>
        <translation type="unfinished">Σκούρο ματζέντα</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Dark Yellow</source>
        <translation type="unfinished">Σκούρο κίτρινο</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Black</source>
        <translation type="unfinished">Μαύρο</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Gray</source>
        <translation type="unfinished">Γκρι</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Light Gray</source>
        <translation type="unfinished">Ανοιχτό γκρι</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>White</source>
        <translation type="unfinished">Λευκό</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Others...</source>
        <translation type="unfinished">Άλλοι...</translation>
    </message>
</context>
<context>
    <name>RDocumentVariables</name>
    <message>
        <location filename="../src/core/RDocumentVariables.cpp" line="+48"/>
        <source>Current Layer ID</source>
        <translation type="unfinished">Τρέχον αναγνωριστικό στρώματος</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Drawing Unit</source>
        <translation type="unfinished">Μονάδα σχεδίασης</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Linetype Scale</source>
        <translation type="unfinished">Κλίμακα τύπου γραμμής</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Dimension Font</source>
        <translation type="unfinished">Γραμματοσειρά διάστασης</translation>
    </message>
</context>
<context>
    <name>REntity</name>
    <message>
        <location filename="../src/core/RBlock.cpp" line="+67"/>
        <location filename="../src/core/RLayer.cpp" line="+95"/>
        <location filename="../src/core/RLayerState.cpp" line="+46"/>
        <location filename="../src/core/RLayout.cpp" line="+81"/>
        <source>Name</source>
        <translation type="unfinished">Όνομα</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Hidden</source>
        <translation type="unfinished">Κρυφό</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Pixel Unit</source>
        <translation type="unfinished">Μονάδα Pixel</translation>
    </message>
    <message>
        <location line="+1"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Origin</source>
        <translation type="unfinished">Προέλευση</translation>
    </message>
    <message>
        <location line="-2"/>
        <location filename="../src/core/RBlockReferenceEntity.cpp" line="+99"/>
        <location line="+3"/>
        <location filename="../src/core/RLayout.cpp" line="+2"/>
        <location line="+3"/>
        <location line="+3"/>
        <location line="+3"/>
        <location line="+3"/>
        <location filename="../src/core/RTextBasedEntity.cpp" line="+75"/>
        <location filename="../src/core/RViewportEntity.cpp" line="+80"/>
        <location line="+8"/>
        <location line="+2"/>
        <source>X</source>
        <translation type="unfinished">X</translation>
    </message>
    <message>
        <location line="+1"/>
        <location filename="../src/core/RBlockReferenceEntity.cpp" line="-2"/>
        <location line="+3"/>
        <location filename="../src/core/RLayout.cpp" line="-11"/>
        <location line="+3"/>
        <location line="+3"/>
        <location line="+3"/>
        <location line="+3"/>
        <location filename="../src/core/RTextBasedEntity.cpp" line="+1"/>
        <location filename="../src/core/RViewportEntity.cpp" line="-9"/>
        <location line="+8"/>
        <location line="+2"/>
        <source>Y</source>
        <translation type="unfinished">Y</translation>
    </message>
    <message>
        <location line="+1"/>
        <location filename="../src/core/RBlockReferenceEntity.cpp" line="-2"/>
        <location line="+3"/>
        <location filename="../src/core/RLayout.cpp" line="-11"/>
        <location line="+3"/>
        <location line="+3"/>
        <location line="+3"/>
        <location line="+3"/>
        <location filename="../src/core/RTextBasedEntity.cpp" line="+1"/>
        <location filename="../src/core/RViewportEntity.cpp" line="-9"/>
        <location line="+10"/>
        <source>Z</source>
        <translation type="unfinished">Z</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Layout</source>
        <translation type="unfinished">Διάταξη</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Owned by Reference</source>
        <translation type="unfinished">Κατέχεται από Αναφορά</translation>
    </message>
    <message>
        <location filename="../src/core/RBlockReferenceData.cpp" line="+886"/>
        <source>Circular (recursive) block referencing detected:</source>
        <translation type="unfinished">Εντοπίστηκε κυκλική (αναδρομική) αναφορά σε μπλοκ:</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Block name:</source>
        <translation type="unfinished">Όνομα μπλοκ:</translation>
    </message>
    <message>
        <location filename="../src/core/RBlockReferenceEntity.cpp" line="-6"/>
        <source>Referenced Block</source>
        <translation type="unfinished">Αναφερόμενο μπλοκ</translation>
    </message>
    <message>
        <location line="+1"/>
        <location line="+1"/>
        <location line="+1"/>
        <location filename="../src/core/RViewportEntity.cpp" line="-12"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Position</source>
        <translation type="unfinished">Θέση</translation>
    </message>
    <message>
        <location line="+1"/>
        <location line="+1"/>
        <location line="+1"/>
        <location filename="../src/core/RViewportEntity.cpp" line="+3"/>
        <source>Scale</source>
        <translation type="unfinished">Κλίμακα</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Angle</source>
        <translation type="unfinished">Γωνία</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Columns</source>
        <translation type="unfinished">Στήλες</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Rows</source>
        <translation type="unfinished">Σειρές</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Column Spacing</source>
        <translation type="unfinished">Απόσταση στηλών</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Row Spacing</source>
        <translation type="unfinished">Απόσταση γραμμής</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Attributes</source>
        <translation type="unfinished">Χαρακτηριστικά</translation>
    </message>
    <message>
        <location filename="../src/core/RDimStyle.cpp" line="+71"/>
        <source>Style</source>
        <translation type="unfinished">Στυλ</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Overall scale</source>
        <translation type="unfinished">Συνολική κλίμακα</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Linear measurement factor</source>
        <translation type="unfinished">Γραμμικός παράγοντας μέτρησης</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Text height</source>
        <translation type="unfinished">Ύψος κειμένου</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Dimension line gap</source>
        <translation type="unfinished">Χάσμα γραμμής διάστασης</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Arrow size</source>
        <translation type="unfinished">Μέγεθος βέλους</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Dimension line increment</source>
        <translation type="unfinished">Προσαύξηση γραμμής διάστασης</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Extension line extension</source>
        <translation type="unfinished">Επέκταση γραμμής επέκτασης</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Extension line offset</source>
        <translation type="unfinished">Μετατόπιση γραμμής επέκτασης</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Text position vertical</source>
        <translation type="unfinished">Θέση κειμένου κάθετα</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Text horizontal</source>
        <translation type="unfinished">Κείμενο οριζόντιο</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Tick size</source>
        <translation type="unfinished">Μέγεθος τσιμπούρι</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Linear format</source>
        <translation type="unfinished">Γραμμική μορφή</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Decimal places</source>
        <translation type="unfinished">Δεκαδικά ψηφία</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Decimal separator</source>
        <translation type="unfinished">Δεκαδικός διαχωριστής</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Zero suppression</source>
        <translation type="unfinished">Μηδενική καταστολή</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Angular format</source>
        <translation type="unfinished">Γωνιακή μορφή</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Angular decimal places</source>
        <translation type="unfinished">Γωνιακά δεκαδικά ψηφία</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Angular zero suppression</source>
        <translation type="unfinished">Καταστολή γωνιακού μηδενός</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Architectur tick</source>
        <translation type="unfinished">Architectur tick</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Text color</source>
        <translation type="unfinished">Χρώμα κειμένου</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Arrow block</source>
        <translation type="unfinished">Μπλοκ βέλους</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Arrow block 1</source>
        <translation type="unfinished">Μπλοκ βέλους 1</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Arrow block 2</source>
        <translation type="unfinished">Μπλοκ βέλους 2</translation>
    </message>
    <message>
        <location filename="../src/core/REntity.cpp" line="+94"/>
        <location filename="../src/core/RObject.cpp" line="+70"/>
        <source>Type</source>
        <translation type="unfinished">Τύπος</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Block</source>
        <translation type="unfinished">Μπλοκ</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Layer</source>
        <translation type="unfinished">Στρώμα</translation>
    </message>
    <message>
        <location line="+1"/>
        <location filename="../src/core/RLayer.cpp" line="+9"/>
        <source>Linetype</source>
        <translation type="unfinished">Linetype</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Linetype Scale</source>
        <translation type="unfinished">Κλίμακα τύπου γραμμής</translation>
    </message>
    <message>
        <location line="+1"/>
        <location filename="../src/core/RLayer.cpp" line="+1"/>
        <source>Lineweight</source>
        <translation type="unfinished">Γραμμικό βάρος</translation>
    </message>
    <message>
        <location line="+1"/>
        <location filename="../src/core/RLayer.cpp" line="-2"/>
        <source>Color</source>
        <translation type="unfinished">Χρώμα</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Displayed Color</source>
        <translation type="unfinished">Εμφανιζόμενο χρώμα</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Draw Order</source>
        <translation type="unfinished">Σειρά κλήρωσης</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Parent Id</source>
        <translation type="unfinished">Id γονέα</translation>
    </message>
    <message>
        <location line="+2"/>
        <location line="+1"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Boundary</source>
        <translation type="unfinished">Όρια</translation>
    </message>
    <message>
        <location line="-3"/>
        <location filename="../src/core/RLayout.cpp" line="+3"/>
        <source>Left</source>
        <translation type="unfinished">Αριστερά</translation>
    </message>
    <message>
        <location line="+1"/>
        <location filename="../src/core/RLayout.cpp" line="+1"/>
        <source>Bottom</source>
        <translation type="unfinished">Κάτω μέρος</translation>
    </message>
    <message>
        <location line="+1"/>
        <location filename="../src/core/RLayout.cpp" line="+1"/>
        <source>Right</source>
        <translation type="unfinished">Δεξιά</translation>
    </message>
    <message>
        <location line="+1"/>
        <location filename="../src/core/RLayout.cpp" line="+1"/>
        <source>Top</source>
        <translation type="unfinished">Κορυφή</translation>
    </message>
    <message>
        <location line="+2"/>
        <location line="+1"/>
        <source>Size</source>
        <translation type="unfinished">Μέγεθος</translation>
    </message>
    <message>
        <location line="-1"/>
        <location filename="../src/core/RLayout.cpp" line="+1"/>
        <location filename="../src/core/RViewportEntity.cpp" line="-2"/>
        <source>Width</source>
        <translation type="unfinished">Πλάτος</translation>
    </message>
    <message>
        <location line="+1"/>
        <location filename="../src/core/RLayout.cpp" line="+1"/>
        <location filename="../src/core/RViewportEntity.cpp" line="+1"/>
        <source>Height</source>
        <translation type="unfinished">Ύψος</translation>
    </message>
    <message>
        <location filename="../src/core/RLayer.cpp" line="-7"/>
        <source>Off</source>
        <translation type="unfinished">Off</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Frozen</source>
        <translation type="unfinished">Κατεψυγμένο</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Locked</source>
        <translation type="unfinished">Κλειδωμένο</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Collapsed</source>
        <translation type="unfinished">Καταρρεύσει</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Plottable</source>
        <translation type="unfinished">Plottable</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Snappable</source>
        <translation type="unfinished">Snappable</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Off is Freeze</source>
        <translation type="unfinished">Το Off είναι Freeze</translation>
    </message>
    <message>
        <location filename="../src/core/RLayout.cpp" line="-23"/>
        <source>Tab Order</source>
        <translation type="unfinished">Σειρά καρτελών</translation>
    </message>
    <message>
        <location line="+1"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Min Limits</source>
        <translation type="unfinished">Ελάχιστα όρια</translation>
    </message>
    <message>
        <location line="+1"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Max Limits</source>
        <translation type="unfinished">Μέγιστα όρια</translation>
    </message>
    <message>
        <location line="+1"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Insertion Base</source>
        <translation type="unfinished">Βάση εισαγωγής</translation>
    </message>
    <message>
        <location line="+1"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Min Extents</source>
        <translation type="unfinished">Ελάχιστες εκτάσεις</translation>
    </message>
    <message>
        <location line="+1"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Max Extents</source>
        <translation type="unfinished">Μέγιστη έκταση</translation>
    </message>
    <message>
        <location filename="../src/core/RObject.cpp" line="-1"/>
        <location filename="../src/core/RPropertyTypeId.cpp" line="+162"/>
        <source>Custom</source>
        <translation type="unfinished">Προσαρμοσμένο</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Handle</source>
        <translation type="unfinished">Λαβή</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Protected</source>
        <translation type="unfinished">Προστατευμένο</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Selected</source>
        <translation type="unfinished">Επιλεγμένα</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Object Invisible</source>
        <translation type="unfinished">Αντικείμενο Αόρατο</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Working Set</source>
        <translation type="unfinished">Σετ εργασίας</translation>
    </message>
    <message>
        <location filename="../src/core/RTextBasedEntity.cpp" line="-3"/>
        <source>Simple</source>
        <translation type="unfinished">Απλό</translation>
    </message>
    <message>
        <location line="+1"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Text Position</source>
        <translation type="unfinished">Θέση κειμένου</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Text</source>
        <translation type="unfinished">Κείμενο</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Plain Text</source>
        <translation type="unfinished">Απλό κείμενο</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Font Name</source>
        <translation type="unfinished">Όνομα γραμματοσειράς</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Text Height</source>
        <translation type="unfinished">Ύψος κειμένου</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Text Width</source>
        <translation type="unfinished">Πλάτος κειμένου</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Text Angle</source>
        <translation type="unfinished">Γωνία κειμένου</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>X Scale</source>
        <translation type="unfinished">X Κλίμακα</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Bold</source>
        <translation type="unfinished">Τολμηρό</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Italic</source>
        <translation type="unfinished">Πλάγια</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Line Spacing</source>
        <translation type="unfinished">Απόσταση γραμμών</translation>
    </message>
    <message>
        <location line="+1"/>
        <location line="+1"/>
        <source>Alignment</source>
        <translation type="unfinished">Ευθυγράμμιση</translation>
    </message>
    <message>
        <location line="-1"/>
        <source>Horizontal</source>
        <translation type="unfinished">Οριζόντια</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Vertical</source>
        <translation type="unfinished">Κατακόρυφο</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Backward</source>
        <translation type="unfinished">Προς τα πίσω</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Upside Down</source>
        <translation type="unfinished">Ανάποδα</translation>
    </message>
    <message>
        <location filename="../src/core/RViewportEntity.cpp" line="+2"/>
        <source>Rotation</source>
        <translation type="unfinished">Περιστροφή</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>On</source>
        <translation type="unfinished">Στο</translation>
    </message>
    <message>
        <location line="+1"/>
        <location line="+1"/>
        <source>View Center</source>
        <translation type="unfinished">Κέντρο προβολής</translation>
    </message>
    <message>
        <location line="+1"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>View Target</source>
        <translation type="unfinished">Προβολή στόχου</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Overall</source>
        <translation type="unfinished">Συνολικά</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Frozen Layers</source>
        <translation type="unfinished">Κατεψυγμένα στρώματα</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Layer ID</source>
        <translation type="unfinished">Αναγνωριστικό στρώματος</translation>
    </message>
</context>
<context>
    <name>RGuiAction</name>
    <message>
        <location filename="../src/core/RGuiAction.cpp" line="+203"/>
        <source>Requires selection</source>
        <translation type="unfinished">Απαιτεί επιλογή</translation>
    </message>
</context>
<context>
    <name>RLinetype</name>
    <message>
        <location filename="../src/core/RLinetype.cpp" line="+51"/>
        <source>Name</source>
        <translation type="unfinished">Όνομα</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Description</source>
        <translation type="unfinished">Περιγραφή</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Metric</source>
        <translation type="unfinished">Μετρικό</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Pattern</source>
        <translation type="unfinished">Μοτίβο</translation>
    </message>
</context>
<context>
    <name>RLinetypePattern</name>
    <message>
        <location filename="../src/core/RLinetypePattern.cpp" line="+912"/>
        <source>By Layer</source>
        <translation type="unfinished">Με στρώμα</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>By Block</source>
        <translation type="unfinished">Με μπλοκ</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Continuous</source>
        <translation type="unfinished">Συνεχής</translation>
    </message>
    <message>
        <location line="+2"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Border</source>
        <translation type="unfinished">Σύνορα</translation>
    </message>
    <message>
        <location line="+2"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Center</source>
        <translation type="unfinished">Κέντρο</translation>
    </message>
    <message>
        <location line="+2"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Dash dot</source>
        <translation type="unfinished">Τελεία παύλα</translation>
    </message>
    <message>
        <location line="+2"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Dashed</source>
        <translation type="unfinished">Διακεκομμένο</translation>
    </message>
    <message>
        <location line="+2"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Divide</source>
        <translation type="unfinished">Διαχωρίστε το</translation>
    </message>
    <message>
        <location line="+2"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Dot</source>
        <translation type="unfinished">Σημείο</translation>
    </message>
    <message>
        <location line="+2"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Hidden</source>
        <translation type="unfinished">Κρυφό</translation>
    </message>
    <message>
        <location line="+2"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Phantom</source>
        <translation type="unfinished">Φάντασμα</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>ISO dash</source>
        <translation type="unfinished">Παύλα ISO</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>ISO dash space</source>
        <translation type="unfinished">Χώρος παύλας ISO</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>ISO long-dash dot</source>
        <translation type="unfinished">Τελεία με μεγάλη παύλα ISO</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>ISO long-dash double-dot</source>
        <translation type="unfinished">ISO long-dash double-dot</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>ISO long-dash triple-dot</source>
        <translation type="unfinished">ISO long-dash triple-dot</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>ISO dot</source>
        <translation type="unfinished">Κουκκίδα ISO</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>ISO long-dash short-dash</source>
        <translation type="unfinished">ISO long-dash short-dash</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>ISO long-dash double-short-dash</source>
        <translation type="unfinished">ISO long-dash double-short-dash</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>ISO dash dot</source>
        <translation type="unfinished">ISO παύλα τελεία</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>ISO double-dash dot</source>
        <translation type="unfinished">Τελεία με διπλή παύλα ISO</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>ISO dash double-dot</source>
        <translation type="unfinished">ISO παύλα διπλή τελεία</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>ISO double-dash double-dot</source>
        <translation type="unfinished">ISO διπλή παύλα διπλή τελεία</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>ISO dash triple-dot</source>
        <translation type="unfinished">ISO παύλα τριπλή τελεία</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>ISO double-dash triple-dot</source>
        <translation type="unfinished">ISO διπλή παύλα τριπλή τελεία</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Hot Water Supply</source>
        <translation type="unfinished">Παροχή ζεστού νερού</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Hot Water</source>
        <translation type="unfinished">Ζεστό νερό</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Gas Line</source>
        <translation type="unfinished">Γραμμή αερίου</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Batting</source>
        <translation type="unfinished">Κτυπήματα</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Zig Zag</source>
        <translation type="unfinished">Ζιγκ Ζαγκ</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Tracks</source>
        <translation type="unfinished">Κομμάτια</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Fenceline 1</source>
        <translation type="unfinished">Fenceline 1</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Fenceline 2</source>
        <translation type="unfinished">Fenceline 2</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Water</source>
        <translation type="unfinished">Νερό</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Drainage</source>
        <translation type="unfinished">Αποχέτευση</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Drainage Reversed</source>
        <translation type="unfinished">Αποστράγγιση Αντιστρέφεται</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Communication</source>
        <translation type="unfinished">Επικοινωνία</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Electric</source>
        <translation type="unfinished">Ηλεκτρικό</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Low Voltage</source>
        <translation type="unfinished">Χαμηλή τάση</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>High Voltage</source>
        <translation type="unfinished">Υψηλή τάση</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Overhead Power</source>
        <translation type="unfinished">Εναέρια ισχύς</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Foul</source>
        <translation type="unfinished">Foul</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Foul Rising</source>
        <translation type="unfinished">Foul Rising</translation>
    </message>
</context>
<context>
    <name>RLineweight</name>
    <message>
        <location filename="../src/core/RLineweight.cpp" line="+37"/>
        <source>By Layer</source>
        <translation type="unfinished">Με στρώμα</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>By Block</source>
        <translation type="unfinished">Με μπλοκ</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Default</source>
        <translation type="unfinished">Προεπιλογή</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>0.00mm</source>
        <translation type="unfinished">0.00mm</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>0.05mm</source>
        <translation type="unfinished">0.05mm</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>0.09mm</source>
        <translation type="unfinished">0.09mm</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>0.13mm (ISO)</source>
        <translation type="unfinished">0.13mm (ISO)</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>0.15mm</source>
        <translation type="unfinished">0.15mm</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>0.18mm (ISO)</source>
        <translation type="unfinished">0.18mm (ISO)</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>0.20mm</source>
        <translation type="unfinished">0.20mm</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>0.25mm (ISO)</source>
        <translation type="unfinished">0.25mm (ISO)</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>0.30mm</source>
        <translation type="unfinished">0.30mm</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>0.35mm (ISO)</source>
        <translation type="unfinished">0.35mm (ISO)</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>0.40mm</source>
        <translation type="unfinished">0.40mm</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>0.50mm (ISO)</source>
        <translation type="unfinished">0.50mm (ISO)</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>0.53mm</source>
        <translation type="unfinished">0.53mm</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>0.60mm</source>
        <translation type="unfinished">0.60mm</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>0.70mm (ISO)</source>
        <translation type="unfinished">0.70mm (ISO)</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>0.80mm</source>
        <translation type="unfinished">0.80mm</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>0.90mm</source>
        <translation type="unfinished">0.90mm</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>1.00mm (ISO)</source>
        <translation type="unfinished">1.00mm (ISO)</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>1.06mm</source>
        <translation type="unfinished">1.06mm</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>1.20mm</source>
        <translation type="unfinished">1.20mm</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>1.40mm (ISO)</source>
        <translation type="unfinished">1.40mm (ISO)</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>1.58mm</source>
        <translation type="unfinished">1.58mm</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>2.00mm (ISO)</source>
        <translation type="unfinished">2.00mm (ISO)</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>2.11mm</source>
        <translation type="unfinished">2.11mm</translation>
    </message>
</context>
</TS>

